..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

File Dialog Example
===============================================================================

Example demonstrating a File Dialog

.. TIP:: To see this example in action, download it from
 :download:`file_dialog <../../../examples/widgets/file_dialog.enaml>`
 and run::

   $ enaml-run file_dialog.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_file_dialog.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/widgets/file_dialog.enaml
    :language: enaml
